@@ -1,18 +1,8 @@
 #ifndef AWS_COMMON_ALLOCATOR_H
 #define AWS_COMMON_ALLOCATOR_H
-/*
- * Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
- *
- * Licensed under the Apache License, Version 2.0 (the "License").
- * You may not use this file except in compliance with the License.
- * A copy of the License is located at
- *
- *  http://aws.amazon.com/apache2.0
- *
- * or in the "license" file accompanying this file. This file is distributed
- * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
- * express or implied. See the License for the specific language governing
- * permissions and limitations under the License.
+/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
  */
 
 #include <aws/common/macros.h>
@@ -174,7 +164,7 @@ struct aws_allocator *aws_small_block_allocator_new(struct aws_allocator *alloca
  * allocator will otherwise be unaffected.
  */
 AWS_COMMON_API
-void aws_small_block_allocator_destroy(struct aws_allocator *allocator);
+void aws_small_block_allocator_destroy(struct aws_allocator *sba_allocator);
 
 AWS_EXTERN_C_END
 
